==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/GitLabIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GitLabIdentityProviderFluent<A extends io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa();
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa();
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca);
  public java.lang.Boolean hasCa();
  public A withNewCa(java.lang.String name);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> withNewCa();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> editCa();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> editOrNewCa();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public java.lang.String getClientID();
  public A withClientID(java.lang.String clientID);
  public java.lang.Boolean hasClientID();
  
  /**
   * Method is deprecated. use withClientID instead.
   */
  @java.lang.Deprecated
  public A withNewClientID(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildClientSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getClientSecret();
  public io.fabric8.openshift.api.model.SecretNameReference buildClientSecret();
  public A withClientSecret(io.fabric8.openshift.api.model.SecretNameReference clientSecret);
  public java.lang.Boolean hasClientSecret();
  public A withNewClientSecret(java.lang.String name);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapNameReferenceFluent<io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface ClientSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SecretNameReferenceFluent<io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<N>>{
    public N and();
    public N endClientSecret();
    
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/GitLabIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GitLabIdentityProviderFluent<A extends io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa();
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa();
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca);
  public java.lang.Boolean hasCa();
  public A withNewCa(java.lang.String name);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> withNewCa();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> editCa();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> editOrNewCa();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public java.lang.String getClientID();
  public A withClientID(java.lang.String clientID);
  public java.lang.Boolean hasClientID();
  
  /**
   * Method is deprecated. use withClientID instead.
   */
  @java.lang.Deprecated
  public A withNewClientID(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildClientSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getClientSecret();
  public io.fabric8.openshift.api.model.SecretNameReference buildClientSecret();
  public A withClientSecret(io.fabric8.openshift.api.model.SecretNameReference clientSecret);
  public java.lang.Boolean hasClientSecret();
  public A withNewClientSecret(java.lang.String name);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
  public io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapNameReferenceFluent<io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface ClientSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SecretNameReferenceFluent<io.fabric8.openshift.api.model.GitLabIdentityProviderFluent.ClientSecretNested<N>>{
    public N and();
    public N endClientSecret();
    
  }
  
}
